==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/cs-CZ/mail.php <==
<?php

return [
    'acceptance_asset_accepted' => 'Uživatel potvrdil vlastnictví',
    'acceptance_asset_declined' => 'Uživatel zamítl vlastnictví',
    'a_user_canceled' => 'Uživatel zrušil žádost o položku na webu',
    'a_user_requested' => 'Uživatel požádal o položku na webu',
    'accessory_name' => 'Název příslušenství:',
    'additional_notes' => 'Další Poznámky:',
    'admin_has_created' => 'Administrátor pro vás vytvořil účet na stránce :web.',
    'asset' => 'Majetek:',
    'asset_name' => 'Název majetku:',
    'asset_requested' => 'Požadovaný majetek',
    'asset_tag' => 'Inventární číslo',
    'assigned_to' => 'Přiděleno',
    'best_regards' => 'S pozdravem,',
    'canceled' => 'Zrušeno:',
    'checkin_date' => 'Datum převzetí:',
    'checkout_date' => 'Datum vydání:',
    'click_to_confirm' => 'Kliknutím na následující odkaz potvrdíte váš účet pro :web:',
    'click_on_the_link_accessory' => 'Kliknutím na odkaz v dolní části potvrďte, že jste obdrželi příslušné příslušenství.',
    'click_on_the_link_asset' => 'Kliknutím na odkaz v dolní části potvrďte, že jste obdrželi daný produkt.',
    'Confirm_Asset_Checkin' => 'Potvrzení odevzdání předmětu',
    'Confirm_Accessory_Checkin' => 'Potvrzení odevzdání příslušenství',
    'Confirm_accessory_delivery' => 'Potvrďte dodání příslušenství',
    'Confirm_license_delivery' => 'Potvrdit dodání licence',
    'Confirm_asset_delivery' => 'Potvrďte dodání majetku',
    'Confirm_consumable_delivery' => 'Potvrďte dodání spotřebního zboží',
    'current_QTY' => 'Aktuální množství',
    'Days' => 'Dní',
    'days' => 'Dní',
    'expecting_checkin_date' => 'Očekávané datum převzetí:',
    'expires' => 'Vyprší',
    'Expiring_Assets_Report' => 'Hlášení o končících zárukách majetku.',
    'Expiring_Licenses_Report' => 'Hlášení o končící platnosti licencí.',
    'hello' => 'Dobrý den',
    'hi' => 'Ahoj',
    'i_have_read' => 'Přečetl/a jsem si podmínky používání, souhlasím s pravidel používání a obdržel jsem tuto položku.',
    'item' => 'Položka:',
    'Item_Request_Canceled' => 'Požadavek na položku zrušen',
    'Item_Requested' => 'Požadavek na položku',
    'link_to_update_password' => 'Klepnutím na následující odkaz aktualizujte své heslo pro :web:',
    'login_first_admin' => 'Přihlaste se k nové instalaci Snipe-IT pomocí níže uvedených pověření:',
    'login' => 'Uživatelské jméno:',
    'Low_Inventory_Report' => 'Hlášení o nízkých zásobách',
    'inventory_report' => 'Zpráva o majetku',
    'min_QTY' => 'Minimální množství',
    'name' => 'Položka',
    'new_item_checked' => 'Nová položka byla odevzdána pod vaším jménem, podrobnosti jsou uvedeny níže.',
    'password' => 'Heslo:',
    'password_reset' => 'Resetování hesla',

    'read_the_terms' => 'Prosím přečtěte si níže uvedené podmínky použití.',
    'read_the_terms_and_click' => 'Přečtěte si prosím níže uvedené podmínky použití a klikněte na odkaz v dolní části, abyste potvrdili, že jste si přečetli a souhlasili s podmínkami používání, a že jste obdrželi majetek.',
    'requested' => 'Zažádáno:',
    'reset_link' => 'Váš odkaz pro resetování hesla',
    'reset_password' => 'Pro zresetování vašeho hesla klikněte na odkaz:',
    'serial' => 'Sériové číslo',
    'supplier' => 'Dodavatelé',
    'tag' => 'Značka',
    'test_email' => 'Testovací email od Snipe-IT',
    'test_mail_text' => 'Toto je test ze systému Snipe-IT Asset Management System. Pokud jste ho dostali, email funguje :)',
    'the_following_item' => 'Následující položka byla převzata: ',
    'low_inventory_alert' => 'Je zde :count položka která je pod minimálním stavem nebo brzy bude.|Jsou zde :count položky které jsou pod minimálním stavem nebo brzy budou.',
    'assets_warrantee_alert' => 'Je zde :count položka se zárukou končící v následujících :threshold dnech.|Jsou zde :count položek se zárukou končící v následujících :threshold dnech.',
    'license_expiring_alert' => 'Je zde :count licence, které končí platnost v příštích :threshold dnech.|Jsou zde :count licence, kterým končí platnost v příštích :threshold dnech.',
    'to_reset' => 'Pro resetování vašeho hesla vyplňte tento formulář:',
    'type' => 'Typ',
    'upcoming-audits' => 'Je zde :count položka, která má chystaný audit za :threshold dní.|Jsou zde :count položek, který se chystá k auditu za :threshold dní.',
    'user' => 'Uživatel',
    'username' => 'Uživatelské jméno',
    'welcome' => 'Vítej uživateli :name',
    'welcome_to' => 'Vítejte na :web!',
    'your_credentials' => 'Vaše pověření Snipe-IT',
    'Accessory_Checkin_Notification' => 'Příslušenství přidáno v',
    'Asset_Checkin_Notification' => 'Majetek přidán v',
    'Asset_Checkout_Notification' => 'Majetek zkontrolován',
    'License_Checkin_Notification' => 'Licence přidána v',
    'Expected_Checkin_Report' => 'Předpokládaný report o dostupném majetku',
    'Expected_Checkin_Notification' => 'Připomenutí: blížící se lhůta pro :name',
    'Expected_Checkin_Date' => 'Majetek, který vám byl předán, musí být vrácen zpět do :date',
    'your_assets' => 'Zobrazit vaše položky',
    'rights_reserved' => 'Všechna práva vyhrazena.',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/cs-CZ/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Příslušenství přidáno v',
    'Accessory_Checkout_Notification' => 'Příslušenství zkontrolováno',
    'Asset_Checkin_Notification' => 'Majetek přidán v',
    'Asset_Checkout_Notification' => 'Majetek zkontrolován',
    'Confirm_Accessory_Checkin' => 'Potvrzení odevzdání příslušenství',
    'Confirm_Asset_Checkin' => 'Potvrzení odevzdání předmětu',
    'Confirm_accessory_delivery' => 'Potvrďte dodání příslušenství',
    'Confirm_asset_delivery' => 'Potvrďte dodání majetku',
    'Confirm_consumable_delivery' => 'Potvrďte dodání spotřebního zboží',
    'Confirm_license_delivery' => 'Potvrdit dodání licence',
    'Consumable_checkout_notification' => 'Spotřební materiál byl zkontrolován',
    'Days' => 'Dní',
    'Expected_Checkin_Date' => 'Majetek, který vám byl předán, musí být vrácen zpět do :date',
    'Expected_Checkin_Notification' => 'Připomenutí: blížící se lhůta pro :name',
    'Expected_Checkin_Report' => 'Předpokládaný report o dostupném majetku',
    'Expiring_Assets_Report' => 'Hlášení o končících zárukách majetku.',
    'Expiring_Licenses_Report' => 'Hlášení o končící platnosti licencí.',
    'Item_Request_Canceled' => 'Požadavek na položku zrušen',
    'Item_Requested' => 'Požadavek na položku',
    'License_Checkin_Notification' => 'Licence přidána v',
    'License_Checkout_Notification' => 'Licence byla zkontrolována',
    'Low_Inventory_Report' => 'Hlášení o nízkých zásobách',
    'a_user_canceled' => 'Uživatel zrušil žádost o položku na webu',
    'a_user_requested' => 'Uživatel požádal o položku na webu',
    'acceptance_asset_accepted' => 'Uživatel potvrdil vlastnictví',
    'acceptance_asset_declined' => 'Uživatel zamítl vlastnictví',
    'accessory_name' => 'Název příslušenství:',
    'additional_notes' => 'Další Poznámky:',
    'admin_has_created' => 'Administrátor pro vás vytvořil účet na stránce :web.',
    'asset' => 'Majetek:',
    'asset_name' => 'Název majetku:',
    'asset_requested' => 'Požadovaný majetek',
    'asset_tag' => 'Inventární číslo',
    'assets_warrantee_alert' => 'Je zde :count položka se zárukou končící v následujících :threshold dnech.|Jsou zde :count položek se zárukou končící v následujících :threshold dnech.',
    'assigned_to' => 'Přiděleno',
    'best_regards' => 'S pozdravem,',
    'canceled' => 'Zrušeno:',
    'checkin_date' => 'Datum převzetí:',
    'checkout_date' => 'Datum vydání:',
    'checkedout_from' => 'Zkontrolováno od',
    'checkedin_from'  => 'Zaškrtnuto z',
    'checked_into' => 'Ověřeno do',
    'click_on_the_link_accessory' => 'Kliknutím na odkaz v dolní části potvrďte, že jste obdrželi příslušné příslušenství.',
    'click_on_the_link_asset' => 'Kliknutím na odkaz v dolní části potvrďte, že jste obdrželi daný produkt.',
    'click_to_confirm' => 'Kliknutím na následující odkaz potvrdíte váš účet pro :web:',
    'current_QTY' => 'Aktuální množství',
    'days' => 'Dní',
    'expecting_checkin_date' => 'Očekávané datum převzetí:',
    'expires' => 'Vyprší',
    'hello' => 'Dobrý den',
    'hi' => 'Ahoj',
    'i_have_read' => 'Přečetl/a jsem si podmínky používání, souhlasím s pravidel používání a obdržel jsem tuto položku.',
    'inventory_report' => 'Zpráva o majetku',
    'item' => 'Položka:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Je zde :count licence, které končí platnost v příštích :threshold dnech.|Jsou zde :count licence, kterým končí platnost v příštích :threshold dnech.',
    'link_to_update_password' => 'Klepnutím na následující odkaz aktualizujte své heslo pro :web:',
    'login' => 'Uživatelské jméno:',
    'login_first_admin' => 'Přihlaste se k nové instalaci Snipe-IT pomocí níže uvedených pověření:',
    'low_inventory_alert' => 'Je zde :count položka která je pod minimálním stavem nebo brzy bude.|Jsou zde :count položky které jsou pod minimálním stavem nebo brzy budou.',
    'min_QTY' => 'Minimální množství',
    'name' => 'Položka',
    'new_item_checked' => 'Nová položka byla odevzdána pod vaším jménem, podrobnosti jsou uvedeny níže.',
    'notes' => 'Poznámky',
    'password' => 'Heslo:',
    'password_reset' => 'Resetování hesla',
    'read_the_terms' => 'Prosím přečtěte si níže uvedené podmínky použití.',
    'read_the_terms_and_click' => 'Přečtěte si prosím níže uvedené podmínky použití, a klikněte na odkaz v dolní části pro potvrzení, že jste si přečetli a souhlasili s podmínkami použití a obdrželi aktivum.',
    'requested' => 'Zažádáno:',
    'reset_link' => 'Váš odkaz pro resetování hesla',
    'reset_password' => 'Pro zresetování vašeho hesla klikněte na odkaz:',
    'rights_reserved' => 'Všechna práva vyhrazena.',
    'serial' => 'Sériové číslo',
    'snipe_webhook_test' => 'Test integrace Snipe-IT',
    'snipe_webhook_summary' => 'Shrnutí testu integrace Snipe-IT',
    'supplier' => 'Dodavatelé',
    'tag' => 'Značka',
    'test_email' => 'Testovací email od Snipe-IT',
    'test_mail_text' => 'Toto je test ze systému Snipe-IT Asset Management System. Pokud jste ho dostali, email funguje :)',
    'the_following_item' => 'Následující položka byla převzata: ',
    'to_reset' => 'Pro resetování vašeho hesla vyplňte tento formulář:',
    'type' => 'Typ',
    'upcoming-audits' => 'Je zde :count položka, která má chystaný audit za :threshold dní.|Jsou zde :count položek, který se chystá k auditu za :threshold dní.',
    'user' => 'Uživatel',
    'username' => 'Uživatelské jméno',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Vítej uživateli :name',
    'welcome_to' => 'Vítejte na :web!',
    'your_assets' => 'Zobrazit vaše položky',
    'your_credentials' => 'Vaše pověření Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
